@@ -1,4 +1,4 @@
-/*  $Id: BatrachiansEngine.cpp,v 1.22 2006/01/26 02:47:02 sarrazip Exp $
+/*  $Id: BatrachiansEngine.cpp,v 1.23 2008/02/09 03:39:46 sarrazip Exp $
     BatrachiansEngine.cpp - Main engine
 
     batrachians - A fly-eating frog game.
@@ -302,25 +302,25 @@ BatrachiansEngine::BatrachiansEngine(const string &windowManagerCaption,
 
     /*  Lily pads:
     */
-    lilyPadSurfaces[0] = IMG_ReadXPMFromArray(lilypads0_xpm);
+    lilyPadSurfaces[0] = IMG_ReadXPMFromArray(const_cast<char **>(lilypads0_xpm));
     if (lilyPadSurfaces[0] == NULL)
 	throw PixmapLoadError(PixmapLoadError::UNKNOWN, NULL);
-    lilyPadSurfaces[1] = IMG_ReadXPMFromArray(lilypads1_xpm);
+    lilyPadSurfaces[1] = IMG_ReadXPMFromArray(const_cast<char **>(lilypads1_xpm));
     if (lilyPadSurfaces[1] == NULL)
 	throw PixmapLoadError(PixmapLoadError::UNKNOWN, NULL);
-    lilyPadSurfaces[2] = IMG_ReadXPMFromArray(lilypads2_xpm);
+    lilyPadSurfaces[2] = IMG_ReadXPMFromArray(const_cast<char **>(lilypads2_xpm));
     if (lilyPadSurfaces[2] == NULL)
 	throw PixmapLoadError(PixmapLoadError::UNKNOWN, NULL);
-    lilyPadSurfaces[3] = IMG_ReadXPMFromArray(lilypads3_xpm);
+    lilyPadSurfaces[3] = IMG_ReadXPMFromArray(const_cast<char **>(lilypads3_xpm));
     if (lilyPadSurfaces[3] == NULL)
 	throw PixmapLoadError(PixmapLoadError::UNKNOWN, NULL);
-    lilyPadSurfaces[4] = IMG_ReadXPMFromArray(lilypads4_xpm);
+    lilyPadSurfaces[4] = IMG_ReadXPMFromArray(const_cast<char **>(lilypads4_xpm));
     if (lilyPadSurfaces[4] == NULL)
 	throw PixmapLoadError(PixmapLoadError::UNKNOWN, NULL);
-    lilyPadSurfaces[5] = IMG_ReadXPMFromArray(lilypads5_xpm);
+    lilyPadSurfaces[5] = IMG_ReadXPMFromArray(const_cast<char **>(lilypads5_xpm));
     if (lilyPadSurfaces[5] == NULL)
 	throw PixmapLoadError(PixmapLoadError::UNKNOWN, NULL);
-    lilyPadSurfaces[6] = IMG_ReadXPMFromArray(lilypads6_xpm);
+    lilyPadSurfaces[6] = IMG_ReadXPMFromArray(const_cast<char **>(lilypads6_xpm));
     if (lilyPadSurfaces[6] == NULL)
 	throw PixmapLoadError(PixmapLoadError::UNKNOWN, NULL);
 
